//+------------------------------------------------------------------+
//|                                                    #  1.2.mq4 |
//|                                     Copyright 2014, Kolosov D.E. |
//+------------------------------------------------------------------+
#property copyright "Copyright 2014, Kolosov D.E."
#property link      ""
#property version   "1.20"
#property strict
#property indicator_chart_window

extern double risk        =  1.7;      //    
extern double mm          =  0.0;      // : 0 - . ; 1 - ; 2 - 
extern int    min_stop    =  100;       //  (  )
extern int    min_take    =  0;      //  (  )
extern color  colortext   =  clrWhite; //  
extern int    corner      =  1;        //   
extern int    coord_y     =  12;       //  Y
extern int    text_size   =  8;        //  

string        name1       =  "lotq";
string        name2       =  "lossq";
string        name3       =  "profq";
string        name4       =  "lotsq";
double        n           =  1.0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
{   
   if (Digits == 3 || Digits == 5) { 
      n = n*10;
      min_stop = min_stop*10;
      min_take = min_take*10;
   }
   return(INIT_SUCCEEDED);
}

void OnDeinit(const int reason)
{
   Comment("");
   ObjectDelete(name1);
   ObjectDelete(name2);
   ObjectDelete(name3);
   ObjectDelete(name4);
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
{
   
   double Free = 0; string freee = "";
   if      (mm == 0.0)  { Free = AccountFreeMargin(); freee = " (   )"; }
   else if (mm == 1.0)  { Free = AccountBalance();    freee = " (  )";         }
   else if (mm == 2.0)  { Free = AccountEquity();     freee = " (  )";          }
   else                 { Free = AccountBalance();    freee = " (  )";         }
   double LotVal  = MarketInfo(Symbol(),MODE_TICKVALUE)/(MarketInfo(Symbol(),MODE_TICKSIZE)
                   /MarketInfo(Symbol(),MODE_POINT));  // 1   1 
   double Min_Lot = MarketInfo(Symbol(),MODE_MINLOT);
   double Max_Lot = MarketInfo(Symbol(),MODE_MAXLOT);
   double Step    = MarketInfo(Symbol(),MODE_LOTSTEP);
   
   if (LotVal == 0) return (0);
   if (Step   == 0) return (0);
   
   double Lot     = MathFloor((Free*risk/100)/(min_stop*LotVal)/Step)*Step;
   if (Lot < Min_Lot) Lot = Min_Lot;
   if (Lot > Max_Lot) Lot = Max_Lot;
   Lot = NormalizeDouble(Lot,2);
      
   string text1, text2, text3, text4, temp;
   double loss, prof, point_price;
   
   text1 = " " + DoubleToStr(Lot,2) + " (  " + DoubleToStr(risk,2) + "%  SL = " + DoubleToStr(min_stop,1) + ")" + freee;
   
   loss  = Lot*LotVal*min_stop;
   text2 = " : " + DoubleToStr(loss,2) + " " + AccountCurrency();
   
   prof  = Lot*LotVal*min_take;
   text3 = " : " + DoubleToStr(prof,2)  + " " + AccountCurrency() + "   : " + DoubleToStr(min_take,1) + " ";
   
   point_price = Lot*LotVal*n;
   text4 = "     " + DoubleToStr(Lot,2) + ": " + DoubleToStr(point_price,2) + " " + AccountCurrency();
   
   if (corner == 2 || corner == 3) { temp = text4; text4 = text1; text1 = temp; temp = text3; text3 = text2; text2 = temp; }
   
   SetLabel(name1, text1, colortext, 3, coord_y,      corner, text_size);
   SetLabel(name2, text2, colortext, 3, coord_y + 15, corner, text_size);
   SetLabel(name3, text3, colortext, 3, coord_y + 30, corner, text_size);
   SetLabel(name4, text4, colortext, 3, coord_y + 45, corner, text_size);


   return(rates_total);
}
//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
//|  :                                                      |
//|    nm -                                       |
//|    tx -                                                     |
//|    cl -                                                 |
//|    xd -  X                                    |
//|    yd -  Y                                    |
//|    cr -           (0 -  )           |
//|    fs -                (8 -  )            |
//+------------------------------------------------------------------+
void SetLabel(string nm, string tx, color cl, int xd, int yd, int cr, int fs) 
{
   if (ObjectFind(nm) < 0) 
      ObjectCreate(nm, OBJ_LABEL, 0, 0,0);
   
   ObjectSetText(nm, tx, fs);
   ObjectSet(nm, OBJPROP_COLOR    , cl);
   ObjectSet(nm, OBJPROP_XDISTANCE, xd);
   ObjectSet(nm, OBJPROP_YDISTANCE, yd);
   ObjectSet(nm, OBJPROP_CORNER   , cr);
   ObjectSet(nm, OBJPROP_FONTSIZE , fs);
}
//+------------------------------------------------------------------+